<?php
$lang['info_detail_returnid'] = 'Den h&auml;r inst&auml;llningen anv&auml;nds f&ouml;r att best&auml;mma en sida (och d&auml;rf&ouml;r en mall) som ska anv&auml;ndas f&ouml;r att visa detaljsidor. Individualiserad nyhets-detalj webbadresser kommer inte att fungera om den h&auml;r parametern inte &auml;r satt till en giltig sida. Dessutom, om detta &auml;r inst&auml;llt, och ingen detaljside parameter anges p&aring; nyhets taggen, s&aring; kommer detta v&auml;rde att anv&auml;ndas f&ouml;r detaljl&auml;nkar.';
$lang['title_detail_returnid'] = 'Standardsida f&ouml;r detalj visning';
$lang['title_submission_settings'] = 'Inst&auml;llningar vid tillagd nyhet';
$lang['title_fesubmit_settings'] = 'Inst&auml;llningar vid tillagd nyhet fr&aring;n framsidan';
$lang['title_notification_settings'] = 'Notiferingsinst&auml;llningar';
$lang['title_detail_settings'] = 'Inst&auml;llningar f&ouml;r detaljvisningar';
$lang['error_invalidurl'] = 'Ogiltig webbadress <em> (kanske den redan anv&auml;nds, eller om det finns ogiltiga tecken) </ em>';
$lang['url'] = 'Url';
$lang['expired_searchable'] = 'Till&aring;t artiklar som passerat slutdatum att visas i s&ouml;kresultat';
$lang['helpshowall'] = 'Visa alla artiklar, oavsett slutdatum';
$lang['error_invaliddates'] = 'Ett eller flera av datumen som skrevs in &auml;r ogiltigt';
$lang['notify_n_draft_items_sub'] = '%d nyhetsartikel/-artiklar';
$lang['notify_n_draft_items'] = 'Du har <a href="moduleinterface.php?module=News">%d nyhetsartiklar</a> som inte har publicerats';
$lang['unlimited'] = 'Obegr&auml;nsad';
$lang['none'] = 'Ingen';
$lang['anonymous'] = 'Anonym';
$lang['unknown'] = 'Ok&auml;nd';
$lang['fesubmit_redirect'] = 'Sid ID eller alias att &aring;terg&aring; till efter att en nyhetsartikel har blivit tillagd med &quot;fesubmit&quot; funktionen';
$lang['allow_summary_wysiwyg'] = 'Till&aring;telse att anv&auml;nda en WYSIWYG editor i sammanfattningsf&auml;ltet';
$lang['title_browsecat_template'] = 'Redigera mall f&ouml;r kategoribl&auml;ddrare';
$lang['title_browsecat_sysdefault'] = 'Standardmall f&ouml;r kategoribl&auml;ddrare';
$lang['browsecattemplate'] = 'Mallar f&ouml;r kategoribl&auml;ddrare';
$lang['error_filesize'] = 'En uppladdad fil &ouml;verskred den maximalt till&aring;tna filstorleken';
$lang['post_date_desc'] = 'Publiceringsdatum fallande';
$lang['post_date_asc'] = 'Publiceringsdatum stigande';
$lang['expiry_date_desc'] = 'Utg&aring;ngsdatum fallande';
$lang['expiry_date_asc'] = 'Utg&aring;ngsdatum stigande';
$lang['title_desc'] = 'Titel stigande';
$lang['title_asc'] = 'Titel fallande';
$lang['status_desc'] = 'Status Fallande';
$lang['status_asc'] = 'Status Stigande';
$lang['fesubmit_status'] = 'Statusen f&ouml;r nyhetsartiklar som skickas via framsidan/frontend';
$lang['error_invalidfiletype'] = 'Kan inte ladda upp den h&auml;r filtypen';
$lang['error_upload'] = 'Problem uppstod n&auml;r fil laddades upp';
$lang['error_movefile'] = 'Kunde inte skapa filen: %s';
$lang['error_mkdir'] = 'Kunde inte skapa mappen: %s';
$lang['expiry_interval'] = 'Antalet dagar (som standard) innan en artikel utg&aring;r (om &quot;utg&aring;ng&quot; &auml;r vald)';
$lang['removed'] = 'Borttagen';
$lang['msg_contenttype_removed'] = 'Inneh&aring;llstypen nyheter har tagits bort. Placera ist&auml;llet taggen {news} med l&auml;mpliga parametrar i din sidmall eller i din sidas inneh&aring;ll, f&ouml;r att ers&auml;tta den h&auml;r funktionen.';
$lang['delete_selected'] = 'Ta bort valda artiklar';
$lang['areyousure_deletemultiple'] = '&Auml;r du s&auml;ker p&aring; att du vill ta bort alla de h&auml;r nyhetsartiklarna?\nDenna &aring;tg&auml;rden kan inte &aring;ngras!';
$lang['error_templatenamexists'] = 'En mall med detta namn finns redan';
$lang['error_noarticlesselected'] = 'Inga artiklar valdes';
$lang['reassign_category'] = '&Auml;ndra kategori till';
$lang['select'] = 'V&auml;lj';
$lang['approve'] = 'S&auml;tt status till &#039;Publicerad&#039;';
$lang['revert'] = 'S&auml;tt status till &#039;Utkast&#039;';
$lang['hide_summary_field'] = 'G&ouml;m sammanfattningsf&auml;ltet n&auml;r artiklar l&auml;ggs till eller redigeras';
$lang['textbox'] = 'Inmatningsf&auml;lt (input)';
$lang['checkbox'] = 'Kryssruta';
$lang['textarea'] = 'Textruta (textarea)';
$lang['file'] = 'Fil';
$lang['auto_create_thumbnails'] = 'Skapa tumnagelfiler automatiskt f&ouml;r filer med dessa fil&auml;ndelser';
$lang['allowed_upload_types'] = 'Till&aring;t bara filer med dessa fil&auml;ndelser att laddas upp';
$lang['fielddefupdated'] = 'F&auml;ltdefinition uppdateraf';
$lang['editfielddef'] = 'Redigera f&auml;ltdefinition';
$lang['up'] = 'Upp';
$lang['down'] = 'Ner';
$lang['fielddefdeleted'] = 'F&auml;ltdefinition borttagen';
$lang['nameexists'] = 'Ett f&auml;lt med det h&auml;r namnet finns redan';
$lang['notanumber'] = 'Maxl&auml;ngd &auml;r  inte en siffra';
$lang['fielddef'] = 'F&auml;ltdefinition';
$lang['fielddefadded'] = 'F&auml;ltdefinition lades till';
$lang['public'] = 'Allm&auml;n';
$lang['type'] = 'Typ';
$lang['info_maxlength'] = 'Maxl&auml;ngden g&auml;ller bara f&ouml;r textinmatningsf&auml;lt';
$lang['maxlength'] = 'Maxl&auml;ngd';
$lang['addfielddef'] = 'L&auml;gg till f&auml;ltdefinition';
$lang['customfields'] = 'F&auml;ltdefinitioner';
$lang['deprecated'] = 'utg&aring;ngen';
$lang['subject_newnews'] = 'En ny artikel i News har skickats';
$lang['email_subject'] = '&Auml;mnet p&aring; det utg&aring;ende epostmeddelandet';
$lang['email_template'] = 'Format p&aring; epostmeddelanden';
$lang['formsubmit_emailaddress'] = 'Epostadress som ska motta meddelande om nyhetsprenumerationer';
$lang['extra'] = 'Extra ';
$lang['uploadscategory'] = 'Uppladdningskategori';
$lang['title_available_templates'] = 'Tillg&auml;ngliga mallar';
$lang['resettodefault'] = '&Aring;terst&auml;ll till fabriksinst&auml;llningar';
$lang['title_form_template'] = 'Editor f&ouml;r formul&auml;rsmall';
$lang['title_detail_template'] = 'Redigerare f&ouml;r detaljmall';
$lang['title_summary_template'] = 'Redigerare f&ouml;r sammanfattningsmall';
$lang['prompt_templatename'] = 'Mallnamn';
$lang['prompt_template'] = 'Mallkod';
$lang['title_form_sysdefault'] = 'F&ouml;rvald formul&auml;rsmall';
$lang['title_summary_sysdefault'] = 'Standardsammanfattningsmall';
$lang['title_detail_sysdefault'] = 'Standarddetaljmall';
$lang['info_sysdefault2'] = '<strong>Observera:</strong> Den h&auml;r flicken inneh&aring;ller textf&auml;lt som g&ouml;r det m&ouml;jligt f&ouml;r dit att redigera en m&auml;ngd mallar som visas n&auml;r du skapar ett ny summerings-, detalj- eller formul&auml;rsmall. G&auml;llande visningar p&aring;verkas <strong>inte</strong> av att du redigerar inneh&aring;llet och sparar informationen.';
$lang['info_sysdefault'] = '<em>(mall som anv&auml;nds som standard n&auml;r en ny mall v&auml;ljs)</em>';
$lang['template'] = 'Mall';
$lang['prompt_name'] = 'Namn';
$lang['prompt_default'] = 'Standard';
$lang['prompt_newtemplate'] = 'Skapa en ny mall';
$lang['help_pagelimit'] = 'Maximalt antal artiklar att visa (per sida). Om denna parametern inte anges kommer alla matchande artiklar att visas. Om parametern anges, och det finns fler artiklar &auml;n vad som anges i parametern, kommer text och l&auml;nkar l&auml;ggas till s&aring; att man kan navigera genom resultaten.';
$lang['prompt_page'] = 'Sida';
$lang['firstpage'] = '<<';
$lang['prevpage'] = '<';
$lang['nextpage'] = '>';
$lang['lastpage'] = '>>';
$lang['prompt_of'] = 'av';
$lang['prompt_pagelimit'] = 'Sidmax';
$lang['prompt_sorting'] = 'Sortera efter';
$lang['title_filter'] = 'Filter';
$lang['published'] = 'Publicerad';
$lang['draft'] = 'Utkast';
$lang['expired'] = 'Utg&aring;ngen';
$lang['author'] = 'F&ouml;rfattare';
$lang['sysdefaults'] = '&Aring;terst&auml;ll standardinst&auml;llningar';
$lang['restoretodefaultsmsg'] = 'Detta &aring;terst&auml;ller mallarna till standardinst&auml;llningarna. &Auml;r du s&auml;ker p&aring; att du vill forts&auml;tta?';
$lang['addarticle'] = 'Skapa artikel';
$lang['articleadded'] = 'Artikeln har lagts till.';
$lang['articleupdated'] = 'Artikeln har uppdaterats.';
$lang['articledeleted'] = 'Artikeln har tagits bort.';
$lang['addcategory'] = 'Skapa kategori';
$lang['categoryadded'] = 'Kategorin har lagts till.';
$lang['categoryupdated'] = 'Kategorin har uppdaterats.';
$lang['categorydeleted'] = 'Kategorin har tagits bort.';
$lang['addnewsitem'] = 'Skapa nyhetsartikel';
$lang['allcategories'] = 'Alla kategorier';
$lang['allentries'] = 'Alla artiklar';
$lang['areyousure'] = '&Auml;r du s&auml;ker p&aring; att du vill ta bort?';
$lang['articles'] = 'Artiklar';
$lang['cancel'] = 'Avbryt';
$lang['category'] = 'Kategori';
$lang['categories'] = 'Kategorier';
$lang['default_category'] = 'Standard-kategori';
$lang['content'] = 'Inneh&aring;ll';
$lang['dateformat'] = '%s &auml;r inget giltigt yyyy-mm-dd hh:mm:ss format';
$lang['delete'] = 'Ta bort';
$lang['description'] = 'L&auml;gg till, redigera och ta bort nyhetsartiklar';
$lang['formtemplate'] = 'Formul&auml;rsmallar';
$lang['detailtemplate'] = 'Inneh&aring;llsmall';
$lang['default_templates'] = 'F&ouml;rvalda mallar';
$lang['detailtemplateupdated'] = 'Den uppdaterade inneh&aring;llsmallen har sparats till databasen.';
$lang['displaytemplate'] = 'Visa mall';
$lang['edit'] = 'Redigera';
$lang['enddate'] = 'Slutdatum';
$lang['endrequiresstart'] = 'Ett stoppdatum kr&auml;ver ocks&aring; att man anger ett startdatum';
$lang['entries'] = '%s artiklar';
$lang['status'] = 'Status ';
$lang['expiry'] = 'Upph&ouml;rande';
$lang['filter'] = 'Filter ';
$lang['more'] = 'Mer';
$lang['category_label'] = 'Kategori:';
$lang['author_label'] = 'Skrivet av:';
$lang['moretext'] = 'Mera text';
$lang['name'] = 'Namn';
$lang['news'] = 'Nyheter';
$lang['news_return'] = 'Tillbaka';
$lang['newcategory'] = 'Ny kategori';
$lang['needpermission'] = 'Du beh&ouml;ver r&auml;ttigheten &#039;%s&#039; f&ouml;r att g&ouml;ra detta.';
$lang['nocategorygiven'] = 'Ingen kategori angiven';
$lang['startdatetoolate'] = 'Startdatum &auml;r f&ouml;r sent (efter slutdatum?)';
$lang['nocontentgiven'] = 'Inget inneh&aring;ll valt';
$lang['noitemsfound'] = 'Hittade <strong>inga</strong> artiklar i kategori: %s';
$lang['nopostdategiven'] = 'Inget publiceringsdatum angivet';
$lang['note'] = '<em>OBS:</em> Datum m&aring;ste vara p&aring; formatet &#039;yyyy-mm-dd hh:mm:ss&#039;.';
$lang['notitlegiven'] = 'Ingen titel angiven';
$lang['nonamegiven'] = 'Inget namn angett';
$lang['numbertodisplay'] = 'Max antal nyheter som ska visas (om tomt visas alla)';
$lang['print'] = 'Skriv ut';
$lang['postdate'] = 'Publiceringsdatum';
$lang['postinstall'] = 'Kom ih&aring;g att s&auml;tta r&auml;ttigheten &quot;Modify News&quot; f&ouml;r de anv&auml;ndare som ska administrera nyhetsartiklar.';
$lang['selectcategory'] = 'V&auml;lj kategori';
$lang['showchildcategories'] = 'Visa underkategorier';
$lang['sortascending'] = 'Sortera stigande';
$lang['startdate'] = 'Startdatum';
$lang['startoffset'] = 'B&ouml;rja visa fr&aring;n nyhet nummer X';
$lang['startrequiresend'] = 'Ett startdatum kr&auml;ver ocks&aring; att man anger ett stoppdatum';
$lang['submit'] = 'L&auml;gg till';
$lang['summary'] = 'Sammandrag';
$lang['summarytemplate'] = 'Mall f&ouml;r sammandrag';
$lang['summarytemplateupdated'] = 'Nyhetsmallen f&ouml;r sammandrag har uppdaterats.';
$lang['title'] = 'Titel';
$lang['options'] = 'Inst&auml;llningar';
$lang['optionsupdated'] = 'Inst&auml;llningarna har uppdaterats.';
$lang['useexpiration'] = 'Anv&auml;nd stoppdatum';
$lang['eventdesc-NewsArticleAdded'] = 'Skickas n&auml;r en artikel l&auml;ggs till.';
$lang['eventhelp-NewsArticleAdded'] = '<p>Skickas n&auml;r en artikel l&auml;ggs till.</p>
<h4>Parametrar</h4>
<ul>
<li>\&quot;news_id\&quot; - ID p&aring; nyhetsartikeln</li>
<li>\&quot;category_id\&quot; - ID p&aring; kategorin f&ouml;r den h&auml;r artikeln</li>
<li>\&quot;title\&quot; - Titel p&aring; artikeln</li>
<li>\&quot;content\&quot; - Inneh&aring;llet i artikeln</li>
<li>\&quot;summary\&quot; - Summering av artikeln</li>
<li>\&quot;status\&quot; - Statusen p&aring; artikeln (&quot;skriven&quot; eller &quot;publicerad&quot;)</li>
<li>\&quot;start_time\&quot; - Datumet d&aring; artikeln ska b&ouml;rja visas</li>
<li>\&quot;end_time\&quot; - Om slutdatumet ska ignoreras eller inte</li>
</ul>
';
$lang['eventdesc-NewsArticleEdited'] = 'Skickas n&auml;r en artikel redigeras.';
$lang['eventhelp-NewsArticleEdited'] = '<p>Skickas n&auml;r en artikel &auml;r &auml;ndrad.</p>
<h4>Parametrar</h4>
<ul>
<li>\&quot;news_id\&quot; - ID p&aring; nyhetsartikeln</li>
<li>\&quot;category_id\&quot; - ID p&aring; kategorin f&ouml;r den h&auml;r artikeln.</li>
<li>\&quot;title\&quot; - Titel p&aring; artikeln</li>
<li>\&quot;content\&quot; - Inneh&aring;llet i artikeln</li>
<li>\&quot;summary\&quot; - Summering av artikeln</li>
<li>\&quot;status\&quot; - Statusen p&aring; artikeln (&quot;skriven&quot; eller &quot;publicerad&quot;)</li>
<li>\&quot;start_time\&quot; - Datumet d&aring; artikeln ska b&ouml;rja visas</li>
<li>\&quot;end_time\&quot; - Datumet d&aring; artikeln ska sluta visas</li>
<li>\&quot;useexp\&quot; - Om slutdatumet ska ignoreras eller inte</li>
</ul>
';
$lang['eventdesc-NewsArticleDeleted'] = 'Skickas n&auml;r en artikel tas bort.';
$lang['eventhelp-NewsArticleDeleted'] = '<p>Skickas n&auml;r en artikel &auml;r borttagen.</p>
<h4>Parametrar</h4>
<ul>
<li>\&quot;news_id\&quot; - ID p&aring; nyhetsartikeln.</li>
</ul>
';
$lang['eventdesc-NewsCategoryAdded'] = 'Skickas n&auml;r en kategori l&auml;ggs till.';
$lang['eventhelp-NewsCategoryAdded'] = '<p>Skickas n&auml;r en kategori &auml;r tillagd.</p>
<h4>Parametrar</h4>
<ul>
<li>\&quot;category_id\&quot; - ID p&aring; nyhetskategorin</li>
<li>\&quot;name\&quot; - Namnet p&aring; nyhetskategorin</li>
</ul>
';
$lang['eventdesc-NewsCategoryEdited'] = 'Skickas n&auml;r en kategori redigeras.';
$lang['eventhelp-NewsCategoryEdited'] = '<p>Skickas n&auml;r en kategori &auml;r &auml;ndrad.</p>
<h4>Parametrar</h4>
<ul>
<li>\&quot;category_id\&quot; - ID p&aring; nyhetskategorin</li>
<li>\&quot;name\&quot; - Namnet p&aring; nyhetakategorin.</li>
<li>\&quot;origname\&quot; - Ursprungsnamnet p&aring; nyhetakategorin.</li>
</ul>
';
$lang['eventdesc-NewsCategoryDeleted'] = 'Skickas n&auml;r en kategori tas bort.';
$lang['eventhelp-NewsCategoryDeleted'] = '<p>Skickas n&auml;r en kategori tas bort.</p>
<h4>Parametrar</h4>
<ul>
<li>\&quot;category_id\&quot; - ID p&aring; kategorin som togs bort</li>
<li>\&quot;name\&quot; - Namnet p&aring; kategorin som togs bort</li>
</ul>
';
$lang['help_articleid'] = 'Denna parameter fungerar endast i den detaljerade vyn. Den till&aring;ter att specificera vilken nyhetsartikel som visas i detaljerad vy. Om specialv&auml;rdet -1 anv&auml;nds, visar systemet den nyaste, publicerade, ej utg&aring;ngna artikeln.';
$lang['helpnumber'] = 'Max antal artiklar att visa (om tomt visas alla artiklar).';
$lang['helpstart'] = 'B&ouml;rja fr&aring;n nyhet nummer X -- om l&auml;mnas tom visas fr&aring;n f&ouml;rsta nyheten.';
$lang['helpcategory'] = 'Visar endast nyheter i vald kategori. <strong>Anv&auml;nd * efter namnet f&ouml;r att visa underkategorier.</strong> Flera kategorier kan visas, anv&auml;nd kommatecken mellan varje. Om ingen specifik kategori anges s&aring; visas alla nyheter.';
$lang['helpmoretext'] = 'Text som visas efter en artikels sammanfattning. Ett klick p&aring; den visar hela nyhetsartikeln. Om inget anges s&aring; visas &quot;more...&quot;.';
$lang['helpsummarytemplate'] = 'Anv&auml;nd en specifik mall f&ouml;r att styra nyhetssammanfattningen. Mallen m&aring;ste finnas i mappen modules/News/templates.';
$lang['helpformtemplate'] = 'Anv&auml;nd en databasmall f&ouml;r att visa formul&auml;r f&ouml;r artikelredigering. Mallen m&aring;ste finnas och vara synlig i fliken f&ouml;r formul&auml;rsmallar i News administrationen, &auml;ven om den inte beh&ouml;ver vara f&ouml;rvald. Om den h&auml;r parametern inte ange kommer den f&ouml;rvalda mallen anv&auml;ndas.';
$lang['helpbrowsecattemplate'] = 'Anv&auml;nd en databasmall f&ouml;r att visa kategoribl&auml;ddraren. Denna mall m&aring;ste finnas och vara synlig i fliken Mallar f&ouml;r kategoribl&auml;ddring i administrationen f&ouml;r Nyheter, &auml;ven om det inte m&aring;ste vara standardmallen. Om denna parameter inte anges kommer den nuvarande standardmallen markeras att anv&auml;ndas.';
$lang['helpdetailtemplate'] = 'Anv&auml;nd en specifik mall f&ouml;r att styra huvudinneh&aring;llet i artikeln. Mallen m&aring;ste finnas i mappen modules/News/templates.';
$lang['helpsortby'] = 'Anger efter vilket f&auml;lt som sortering ska ske. Alternativen &auml;r: &quot;news_date&quot;, &quot;summary&quot;, &quot;news_data&quot;, &quot;news_category&quot;, &quot;news_title&quot;.  &quot;news_date&quot; anv&auml;nds om inget annat anges.';
$lang['helpsortasc'] = 'Sortera artiklar i stigande datumordning i st&auml;llet f&ouml;r fallande.';
$lang['helpdetailpage'] = 'Sida att visa detaljerna f&ouml;r nyhetsartikeln p&aring;. Detta kan antingen vara ett sidalias eller ett id. Anv&auml;nds f&ouml;r att detaljer ska kunna visas med en annan mall &auml;n sammanfattningen.';
$lang['helpshowarchive'] = 'Visa endast utg&aring;gna nyhetsartiklar.';
$lang['helpbrowsecat'] = 'Visa en s&ouml;kbar kategorilista.';
$lang['helpaction'] = 'Upph&auml;v f&ouml;rvald handling. M&ouml;jliga v&auml;rden &auml;r &#039;default&#039; f&ouml;r att visa summeringsvyn, och &#039;fesubmit&#039; f&ouml;r att visa Frontend-formul&auml;ret f&ouml;r att till&aring;ta anv&auml;ndare att skicka in nyheter via frontend.';
$lang['help'] = '<h3>Important Notes</h3>
<p>This version of News is greater than the one supplied with the 1.1 branch of CMS Made Simple.  If you use this version of News you must use extreme caution when upgrading CMS Made Simple to ensure that nothing in the modules/News directory is overwritten.</p>
<h3>Vad g&ouml;r den h&auml;r modulen?</h3>
	<p>Nyheter &auml;r en modul med vars hj&auml;lp man kan hantera och visa nyhetsartiklar p&aring; sin webbplats. Man kan j&auml;mf&ouml;ra modulen med weblog (blogg), fast nyhetsmodulen har fler funktioner. N&auml;r modulen installeras s&aring; ut&ouml;kas ocks&aring; administrationsgr&auml;nssnittet med verktyg f&ouml;r att hantera nyhetsartiklar. Man ges m&ouml;jlighet att skapa egna nyhetskategorier s&aring; att olika typer av nyheter kan placeras p&aring; olika st&auml;llen p&aring; webbplatsen.</p>
        <h4>Numerous display methods</h4>
	<p>The parameters supported by the news module, and support for numerous templates of each time mean that your options for displaying news articles are limitless.</p>
        <h4>Custom Fields</h4>
	<p>The News module allows defining numerous custom fields (including files and images) that will allow you to attach pdf files or numerous images to your articles.</p>
        <h4>Categories</h4>
	<p>News supplies a hierarchical category mechanism for organizing your articles.  A news article can only be in one place in the hierarchy.</p>
        <h4>RSS Feeds</h4>
        <p>News supports generating simple rss feeds from your news articles, so that your visitors can always be up to date with what is happening on your site.</p>
	<h4>Expiry and Status</h4>
	<p>Each news article can have an optional expiry date, after which it will not be shown on your web page.  As well, articles can be marked as <em>draft</em> to remove them permanently from your web page.</p>
	<h3>S&auml;kerhet</h3>
	<p>En anv&auml;ndare m&aring;ste tillh&ouml;ra gruppen &#039;Modify News&#039; f&ouml;r att kunna l&auml;gga till, redigera eller ta bort nyhetsartiklar.</p>
<p>As well, In order to delete news entries, the user must belong to a group with the &#039;Delete News Articles&#039; permission.</p>
	<p>F&ouml;r att redigera layoutmallarna m&aring;ste anv&auml;ndaren tillh&ouml;ra en grupp med r&auml;ttigheten &#039;Modify Templates&#039;.</p>
	<p>F&ouml;r att redigera globala nyhetsinst&auml;llningar m&aring;ste anv&auml;ndaren tillh&ouml;ra en grupp med r&auml;ttigheten &#039;Modify Site Preferences&#039;.</p>
<p>Additionally, to approve news for frontend display the user must belong to a group with the &#039;Approve News&#039; permission.</p>
	<h3>Hur anv&auml;nder man modulen?</h3>
	<p>Enklast &auml;r att anv&auml;nda taggen {news} (som &auml;r ett h&ouml;lje runt modultaggen, f&ouml;r att f&ouml;renkla syntaxet). Med denna tagg kan man l&auml;gga till och visa nyheter p&aring; valfri plats i en mall eller en sida. Koden f&ouml;r detta kan till exempel se ut s&aring; h&auml;r: <code>{news number=&quot;5&quot;}</code></p>
<h3>Templates</h3>
	<p>Since version 2.3 News supports multiple database templates, and no longer supports additional file templates.  Users who used the old file template system should follow these steps (for each file template):
<ul>
<li>Copy the file template into the clipboard</li>
<li>Create a new database template <em>(either summary or detailed as required)</em>.  Give the new template the same name (including the .tpl extension) as the old file template, and paste the contents.</li>
<li>Hit Submit</li>
</ul>
Following these steps should solve the problem of your news templates not being found and other similar smarty errors when you upgrade to a version of CMS that has News 2.3 or greater.</p>';
$lang['utma'] = '156861353.622613290.1282068801.1286133816.1286141542.24';
$lang['utmz'] = '156861353.1284652314.14.4.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
$lang['qca'] = 'P0-1267218368-1282068801788';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.1.10.1286141542';
?>